@@ -4,9 +4,8 @@ __all__ = (
     "caching",
     "config",
     "connection",
-    "consumer",
+    "streamer",
     "health",
-    "sender",
 )
 
 
